﻿using System.Collections.Generic;
using BlockMania.Global;
using BlockMania.Util;
using BlockMania.View;

namespace BlockMania.GeneralStates.Screen_02_Play
{
	internal static class RowMarker
	{
		internal enum MarkState
		{
			IN_PROGRESS,
			FINISHED
		}
		internal static MarkState markState = MarkState.FINISHED;

		internal enum ActionType
		{
			MARK,
			REMOVE
		}
		private static ActionType actionType = ActionType.MARK;

		private static readonly Delay delay = new Delay(30);
		private static List<int> rowsToMark = new List<int>();

		private static int rowIndex;
		private static int colIndex;

		internal static void Start(List<int> rows, ActionType action)
		{
			rowsToMark = rows;

			rowIndex = 0;
			colIndex = 0;

			markState = MarkState.IN_PROGRESS;
			actionType = action;
		}

		internal static void HandleGameTick()
		{
			MarkTiles();
		}

		private static void MarkTiles()
		{
			if (markState != MarkState.FINISHED && delay.HasExpired())
			{
				int row = rowsToMark[rowIndex];
				MarkOrRemoveTile(row, colIndex);

				colIndex++;
				if (colIndex == GlobalData.COL_COUNT)
				{
					colIndex = 0;
					rowIndex++;
				}

				if (rowIndex == rowsToMark.Count)
				{
					markState = MarkState.FINISHED;
				}
			}
		}

		private static void MarkOrRemoveTile(int row, int col)
		{
			switch (actionType)
			{
				case ActionType.MARK   : MarkTile(  row,  col) ; break;
				case ActionType.REMOVE : RemoveTile(row,  col) ; break;
			}
		}

		private static void MarkTile(int row, int col)
		{
			Gamefield.grid[row, col] += 100;
		}

		private static void RemoveTile(int row, int col)
		{
			Gamefield.RemoveTile(row, col);
		}

	}
}