﻿using BlockMania.Global;
using BlockMania.Util;
using BlockMania.Util.BlockTools;
using BlockMania.View;

namespace BlockMania.GeneralStates.Screen_02_Play
{
	internal static class State_01_Regular
	{
		private static readonly Delay delayKeyRepeat = new Delay(100);

		private static readonly Block dummyBlock = BlockTool.CeateBlock(0);

		internal static void HandleGameTick(UserInput input, bool isNotRepeating)
		{
			GameLoop(input, isNotRepeating);
		}

		private static void GameLoop(UserInput input, bool isNotRepeating)
		{
			if (Gamefield.IsErEenBlockOpHetGamefield())
			{
				HandleInput(input, isNotRepeating);
			}

			if (Gamefield.IsErEenBlockOpHetGamefield())
			{
				if (is_het_tijd_voor_een_move_down())
				{
					MoveBlockDown();
				}
			}
			else // Er is nog [geen] block op het veld.
			{
				MovePreviewBlockToField();
			}
		}

		private static bool is_het_tijd_voor_een_move_down()
		{
			return BlockSpeed.DELAY.HasExpired();
		}

		private static void MoveBlockDown()
		{
			CopyTool.Copy(Gamefield.GetBlock(), dummyBlock);
			dummyBlock.IncrementRowOffset();
			TileTool.RefreshTiles(dummyBlock);

			if (LocationCheckTool.VallenAlleBlockTileLocatiesBinnenDeGamefieldGrens(dummyBlock) &&
			    LocationCheckTool.ZijnAlleBlockTileLocatiesVrijOpHetGamefield(dummyBlock))
			{
				CopyTool.Copy(dummyBlock, Gamefield.GetBlock());
			}
			else
			{
				Gamefield.MakeBlockPermanent();
				if (RowCheckTool.HasGamefieldClearedRows())
				{
					Screen_2_Play.SwitchToRowRemoval();
				}
			}
		}

		private static void HandleInput(UserInput input, bool isNotRepeating)
		{
			if (input == UserInput.SELECT_BLOCK && isNotRepeating)
			{
				PreviewField.SetNextBlock();
			}
			else if ((input == UserInput.ROTATE || input == UserInput.FLIP) && isNotRepeating)
			{
				MoveOrRotateBlock(input);
			}
			else
			{
				if (isNotRepeating)
				{
					HandleMove(input);
					delayKeyRepeat.Reset();
				}
				else
				{
					if (delayKeyRepeat.HasExpired())
					{
						HandleMove(input);
					}
				}
			}
		}

		private static void HandleMove(UserInput input)
		{
			switch (input)
			{
				case UserInput.MOVE_UP    :
				case UserInput.MOVE_LEFT  :
				case UserInput.MOVE_RIGHT : MoveOrRotateBlock(input) ; break;
				case UserInput.MOVE_DOWN  : MoveBlockDown()          ; break;
			}
		}

		private static void MovePreviewBlockToField()
		{
			CopyTool.Copy(PreviewField.GetBlock(), dummyBlock);

			OffsetTool.CalculateInitialColOffset(dummyBlock);
			TileTool.RefreshTiles(dummyBlock);

			if (LocationCheckTool.ZijnAlleBlockTileLocatiesVrijOpHetGamefield(dummyBlock))
			{
				Block block_new = BlockTool.CeateBlock(0);
				CopyTool.Copy(dummyBlock, block_new);

				Gamefield.SetBlock(block_new);
				PreviewField.SetRandomBlock();

				BlockSpeed.DELAY.Reset();
			}
			else
			{
				HandleGameOver();
			}
		}

		private static void HandleGameOver()
		{
			Screen_2_Play.SwitchToGameOver();
		}

		private static void MoveOrRotateBlock(UserInput input)
		{
			CopyTool.Copy(Gamefield.GetBlock(), dummyBlock);

			switch (input)
			{
				// case UserInput.MOVE_UP    : dummyBlock.DecrementRowOffset()    ; break;
				case UserInput.MOVE_DOWN  : dummyBlock.IncrementRowOffset()    ; break;
				case UserInput.MOVE_LEFT  : dummyBlock.DecrementColOffset()    ; break;
				case UserInput.MOVE_RIGHT : dummyBlock.IncrementColOffset()    ; break;
				case UserInput.ROTATE     : BlockRotateTool.Rotate(dummyBlock) ; break;
				case UserInput.FLIP       : BlockFlipTool.Flip(dummyBlock)     ; break;
			}

			TileTool.RefreshTiles(dummyBlock);

			if (LocationCheckTool.VallenAlleBlockTileLocatiesBinnenDeGamefieldGrens(dummyBlock) &&
					LocationCheckTool.ZijnAlleBlockTileLocatiesVrijOpHetGamefield(dummyBlock))
			{
				CopyTool.Copy(dummyBlock, Gamefield.GetBlock());
			}
		}
		
	}
}