﻿using System.Drawing;
using BlockMania.Global;
using BlockMania.Util;

namespace BlockMania.GeneralStates.Screen_02_Play
{
	internal static class State_04_Game_Over
	{
		private static readonly Delay delay = new Delay(1000 * 10);

		private static TextBlinking text01;

		private static int width;
		private static int height;

		internal static void Init()
		{
			const string TEXT = "game over";
			Font font = FontManager.font_65;
			const int Y = 205;
			int X = Tools.CalculateXforStringOnGamefield(TEXT, font);
			text01 = new TextBlinking(TEXT, font, GlobalColors.BRUSH_YELLOW, 1000, X, Y);

			SizeF stringSize = Tools.GetStringSize(TEXT, font);
			width  = (int) (stringSize.Width  + 30);
			height = (int) (stringSize.Height + 45);
		}

		internal static void Reset()
		{
			delay.Reset();
			text01.Reset();
		}

		internal static void HandleGameTick(UserInput input, bool isNotRepeating)
		{
			HandleInput(input, isNotRepeating);
			Draw();

			if (delay.HasExpired())
				SwitchToHomeScreen();
		}

		private static void HandleInput(UserInput input, bool isNotRepeating)
		{
			if (input == UserInput.ESCAPE && isNotRepeating)
			{
				SwitchToHomeScreen();
			}
		}

		private static void SwitchToHomeScreen()
		{
			GlobalController.SwitchToHome();
		}

		private static void Draw()
		{
			if (text01.toggle) // Synchronize with the blinking-rate of the text.
			{
				Tools.DrawRectangleWithBorderAndFill(
					text01.x - 20, text01.y - 20,
					width, height,
					GlobalData.GAME_FIELD_BORDER_WIDTH,
					GlobalColors.GAME_FIELD_BORDER_COLOR,
					GlobalColors.BRUSH_RED
					);
			}

			text01.HandleGameTick();
		}

	}
}