﻿using System.Drawing;
using BlockMania.GeneralStates.Screen_01_Home;
using BlockMania.GeneralStates.Screen_02_Play;
using BlockMania.Global;
using BlockMania.Util;

namespace BlockMania.GeneralStates.Screen_03_Settings
{
	internal static class Screen_3_Settings
	{
		private static readonly Delay delayKeyRepeat = new Delay(150);

		private enum ScreenState
		{
			REGULAR,
			TRANSITION
		}
		private static ScreenState screenState = ScreenState.REGULAR;

		private static TextStatic textTitle;
		private static TextStatic textSettings;

		private static NumberIndicator numberIndicator;

		private static Checkbox checkboxAdjustSpeed;
		private static Checkbox checkboxExtraBlocks;
		private static Checkbox checkboxShowGrid;

		private static TextStatic textPlay;
		private static TextStatic textHelp;

		internal static bool settingsAreChanged;

		internal static void Init()
		{
			string text = GlobalData.WINDOW_TITLE;
			Font font = FontManager.font_65;
			int Y = 20;
			int X = Tools.CalculateXforStringOnPanel(text, font);
			textTitle = new TextStatic(text, font, GlobalColors.BRUSH_YELLOW, X, Y);

			text = "settings";
			font = FontManager.font_40;
			Y = textTitle.y + 65;
			X = Tools.CalculateXforStringOnPanel(text, font);
			textSettings = new TextStatic(text, font, GlobalColors.BRUSH_PINK, X, Y);

			X = 200;
			Y = 160;
			numberIndicator = new NumberIndicator("Speed", SettingStorage.speed.ToString(), "F5 / F6", X, Y);

			X = 60;
			Y += 170;
			checkboxAdjustSpeed = new Checkbox("gradually", "increase", "speed", SettingStorage.levelUp, "F7", X, Y);

			X += 500;
			checkboxExtraBlocks = new Checkbox("add", "extra", "blocks", SettingStorage.extraBlocks, "F8", X, Y);

			X = 370;
			Y += 220;
			checkboxShowGrid = new Checkbox("show", "grid", null, SettingStorage.showGrid, "F9", X, Y);

			text = "play : F1";
			font = FontManager.font_40;
			Y = GlobalData.PANEL_HEIGHT - 60;
			X = 20;
			textPlay = new TextStatic(text, font, GlobalColors.BRUSH_PINK, X, Y);

			text = "help : F4";
			font = FontManager.font_40;
			X = 795;
			textHelp = new TextStatic(text, font, GlobalColors.BRUSH_PINK, X, Y);
		}

		internal static void SwitchToNormalState()
		{
			screenState = ScreenState.REGULAR;
		}

		private static void SwitchToTransitionState()
		{
			screenState = ScreenState.TRANSITION;
		}

		internal static void HandleGameTick(UserInput input, bool isNotRepeating)
		{
			Draw();

			switch (screenState)
			{
				case ScreenState.REGULAR    : HandleInput(input, isNotRepeating) ; break;
				case ScreenState.TRANSITION : Transition.TriggerPartOne() ; break;
			}
		}

		private static void HandleInput(UserInput input, bool isNotRepeating)
		{
			if (input == UserInput.SWITCH_TO_PLAY && isNotRepeating)
			{
				SwitchToTransitionState();
			}
			else
			{
				if (isNotRepeating)
				{
					HandleInput(input);
					delayKeyRepeat.Reset();
				}
				else
				{
					if (delayKeyRepeat.HasExpired())
					{
						HandleInput(input);
					}
				}
			}
		}

		private static void HandleInput(UserInput input)
		{
			switch (input)
			{
				case UserInput.SWITCH_TO_PLAY : SwitchToTransitionState() ; break;
				case UserInput.F5 : DecreaseSpeed()                       ; break;
				case UserInput.F6 : IncreaseSpeed()                       ; break;
				case UserInput.F7 : ToggleGraduallyIncreaseSpeed()        ; break;
				case UserInput.F8 : ToggleAddExtraBlocks()                ; break;
				case UserInput.F9 : ToggleGamefieldGrid()                 ; break;
			}
		}

		private static void IncreaseSpeed()
		{
			BlockSpeed.Increase();
			UpdateSpeed();
		}

		private static void DecreaseSpeed()
		{
			BlockSpeed.Decrease();
			UpdateSpeed();
		}

		private static void UpdateSpeed()
		{
			SettingStorage.speed = BlockSpeed.speed;
			numberIndicator.SetNumber(BlockSpeed.speed);
			settingsAreChanged = true;
		}

		private static void ToggleGraduallyIncreaseSpeed()
		{
			SettingStorage.levelUp = ! SettingStorage.levelUp;
			checkboxAdjustSpeed.SetChecked(SettingStorage.levelUp);
			settingsAreChanged = true;
		}

		private static void ToggleAddExtraBlocks()
		{
			SettingStorage.extraBlocks = ! SettingStorage.extraBlocks;
			checkboxExtraBlocks.SetChecked(SettingStorage.extraBlocks);
			settingsAreChanged = true;
		}

		private static void ToggleGamefieldGrid()
		{
			SettingStorage.showGrid = ! SettingStorage.showGrid;
			checkboxShowGrid.SetChecked(SettingStorage.showGrid);
			settingsAreChanged = true;
		}

		private static void Draw()
		{
			textTitle.HandleGameTick();
			textSettings.HandleGameTick();

			numberIndicator.HandleGameTick();
			checkboxAdjustSpeed.HandleGameTick();
			checkboxExtraBlocks.HandleGameTick();
			checkboxShowGrid.HandleGameTick();

			textPlay.HandleGameTick();
			textHelp.HandleGameTick();
		}

	}
}