﻿using System;
using System.Drawing;
using BlockMania.Global;

namespace BlockMania.Util
{
	internal class Checkbox
	{
		private readonly int x;
		private readonly int y;

		private readonly Font font = FontManager.font_50;

		private readonly TextStatic label_01;
		private readonly TextStatic label_02;
		private readonly TextStatic label_03;
		private readonly TextStatic labelShortcut;

		private readonly int width;
		private readonly int height;

		private readonly int x2;
		private readonly int y2;

		private readonly bool hasThreeTexts;

		private const int SPACER = 45;

		private bool isChecked;

		internal Checkbox(string text_01, string text_02, string text_03, bool isChecked, string shortcut, int x, int y)
		{
			this.x = x;
			this.y = y;

			this.isChecked = isChecked;

			SizeF stringSize_01 = GlobalCanvas.canvas.MeasureString(text_01, font);
			int width_01 = (int) stringSize_01.Width;

			SizeF stringSize_02 = GlobalCanvas.canvas.MeasureString(text_02, font);
			int width_02 = (int) stringSize_02.Width;

			hasThreeTexts = ! string.IsNullOrEmpty(text_03);

			int width_03 = 0;
			if (hasThreeTexts)
			{
				SizeF stringSize_03 = GlobalCanvas.canvas.MeasureString(text_03, font);
				width_03 = (int) stringSize_03.Width;
			}

			width = Math.Max(Math.Max(width_01, width_02), width_03) + 115;
			height = (hasThreeTexts ? 170 : 140);

			int x1 = x + 100;
			int y1 = y + 10;

			x2 = x + 30;
			y2 = y + 30;

			label_01 = new TextStatic(text_01, font, GlobalColors.BRUSH_YELLOW, x1, y1);
			y1 += SPACER;
			label_02 = new TextStatic(text_02, font, GlobalColors.BRUSH_YELLOW, x1, y1);

			if (hasThreeTexts)
			{
				y1 += SPACER;
				label_03 = new TextStatic(text_03, font, GlobalColors.BRUSH_YELLOW, x1, y1);
			}

			labelShortcut = new TextStatic(shortcut, font, GlobalColors.BRUSH_PINK, x + width + 20, y + height - 70);
		}

		internal void SetChecked(bool b)
		{
			isChecked = b;
		}

		internal void HandleGameTick()
		{
			Draw();
		}

		private void Draw()
		{
			Tools.DrawRectangleWithBorderAndFill(x, y, width, height, 2, GlobalColors.BRUSH_PINK, GlobalColors.BRUSH_RED);
			Tools.DrawRectangleWithBorderAndFill(x2, y2,50, 50, 2, GlobalColors.BRUSH_WHITE, GlobalColors.BRUSH_RED);

			if (isChecked)
			{
				Tools.DrawRectangleWithBorderAndFill(x2 + 10, y2 + 10,30, 30, 2, GlobalColors.BRUSH_WHITE, GlobalColors.BRUSH_WHITE);
			}

			label_01.HandleGameTick();
			label_02.HandleGameTick();

			if (hasThreeTexts)
			{
				label_03.HandleGameTick();
			}

			labelShortcut.HandleGameTick();

		}

	}
}