﻿using System;
using System.Drawing;
using System.Drawing.Text;
using System.IO;
using System.Runtime.InteropServices;

namespace BlockMania.Util
{
	internal static class FontManager
	{
		private static readonly PrivateFontCollection pfc = new PrivateFontCollection();

		internal static Font font_150;
		internal static Font font_65;
		internal static Font font_50;
		internal static Font font_40;

		internal static void Init()
		{
			LoadFont("galactic_storm.ttf");

			font_150 = new Font(pfc.Families[0], 150, GraphicsUnit.Pixel);
			font_65  = new Font(pfc.Families[0], 65,  GraphicsUnit.Pixel);
			font_50  = new Font(pfc.Families[0], 50,  GraphicsUnit.Pixel);
			font_40  = new Font(pfc.Families[0], 40,  GraphicsUnit.Pixel);
		}

		private static void LoadFont(string fontName)
		{
			Stream fontStream = ResourceLocator.GetResourceStream(fontName); // Receive resource stream.
			IntPtr data = Marshal.AllocCoTaskMem((int) fontStream.Length); // Create an unsafe memory block for the font data.
			var fontdata = new byte[fontStream.Length]; // Create a buffer to read in to.

			fontStream.Read(fontdata, 0, (int) fontStream.Length); // Read the font data from the resource.
			Marshal.Copy(fontdata, 0, data, (int) fontStream.Length); // Copy the bytes to the unsafe memory block.
			pfc.AddMemoryFont(data, (int) fontStream.Length); // Pass the font to the font collection.

			fontStream.Close(); // Close the resource stream.
			Marshal.FreeCoTaskMem(data); // Free up the unsafe memory.
		}

	}
}