﻿using System.Threading;

namespace BlockMania.Util.PrecisionTiming.Base
{
	/// <summary>
	/// Semaphore Weak
	/// A Single Entrant Semaphore,
	/// Technically not safe if you use it wrong
	/// </summary>
	internal class SemaphoreWeak
	{
		protected private volatile bool canEnter = true;

		protected private SpinWait SpinWait { get; set; }

		/// <summary>
		/// Returns true if the semaphore is taken
		/// </summary>
		/// <returns>Returns true if the semaphore is taken</returns>
		public bool CanEnter()
		{
			SpinWait.SpinOnce();

			if (!canEnter)
			{
				return false;
			}
			else
			{
				canEnter = false;
				return true;
			}
		}

		/// <summary>
		/// Release the semaphore if it was taken
		/// </summary>
		public void Release()
		{
			canEnter = true;
		}
	}
}