﻿using System;
using BlockMania.Util.PrecisionTiming.Base;
using BlockMania.Util.PrecisionTiming.Multimedia;

namespace BlockMania.Util.PrecisionTiming
{
	/// <summary>
	/// Multimedia Timer Settings
	/// Allows you to configure your application to work better with high resolution timers
	/// </summary>
	internal static class PrecisionTimerSettings
	{
		/// <summary>
		/// Minimum timer resolution, in milliseconds, for the application.
		/// A lower value specifies a higher (more accurate) resolution.
		/// </summary>
		/// <param name="setMinimum">Minimum timer resolution in milliseconds</param>
		internal static void SetMinimumTimerResolution(int setMinimum)
		{
			if (MMTimerExports.timeBeginPeriod(setMinimum) != 0)
				throw new InvalidOperationException(Constants.resolutionNotSupportedString);
		}

		/// <summary>
		/// Clear timer resolution specified in the previous call to the <see cref="SetMinimumTimerResolution"/>
		/// </summary>
		/// <param name="clearSetMinimum">setMinimum specified in the previous call to the <see cref="SetMinimumTimerResolution"/></param>
		internal static void ClearMinimumTimerResolution(int clearSetMinimum)
		{
			if (MMTimerExports.timeEndPeriod(clearSetMinimum) != 0)
				throw new InvalidOperationException(Constants.resolutionNotSupportedString);
		}
	}
}