﻿using System;
using System.Drawing;
using BlockMania.Global;

namespace BlockMania.Util
{
	internal class TextBlock
	{
		internal readonly int x;
		internal readonly int y;

		private Font font = FontManager.font_50;

		private readonly TextStatic label_01;
		private readonly TextStatic label_02;
		private readonly TextStatic label_03;

		private readonly int width;
		private readonly int height;

		private readonly bool hasThreeTexts;

		private const int SPACER = 45;

		internal TextBlock(string text_01, string text_02, string text_03, int x, int y) : this(FontManager.font_50, text_01,text_02,text_03, x, y)
		{
		}

		internal TextBlock(Font font, string text_01, string text_02, string text_03, int x, int y)
		{
			this.font = font;

			this.x = x;
			this.y = y;

			SizeF stringSize_01 = GlobalCanvas.canvas.MeasureString(text_01, font);
			int width_01 = (int) stringSize_01.Width;

			int x1 = 0;
			int y1 = y + 10;

			SizeF stringSize_02 = GlobalCanvas.canvas.MeasureString(text_02, font);
			int width_02 = (int) stringSize_02.Width;

			int x2 = 0;
			int y2 = y1 + SPACER;

			hasThreeTexts = ! string.IsNullOrEmpty(text_03);

			int width_03 = 0;
			if (hasThreeTexts)
			{
				SizeF stringSize_03 = GlobalCanvas.canvas.MeasureString(text_03, font);
				width_03 = (int) stringSize_03.Width;
			}

			width = Math.Max(Math.Max(width_01, width_02), width_03) + 40;
			height = (hasThreeTexts ? 160 : 110);

			x1 = Tools.CalculateXforString(text_01, font, width, x);
			x2 = Tools.CalculateXforString(text_02, font, width, x);

			label_01 = new TextStatic(text_01, font, GlobalColors.BRUSH_WHITE, x1, y1);
			label_02 = new TextStatic(text_02, font, GlobalColors.BRUSH_YELLOW, x2, y2);

			if (hasThreeTexts)
			{
				int x3 = Tools.CalculateXforString(text_03, font, width, x);
				int y3 = y2 + SPACER;
				label_03 = new TextStatic(text_03, font, GlobalColors.BRUSH_YELLOW, x3, y3);
			}
		}

		internal void HandleGameTick()
		{
			Draw();
		}

		private void Draw()
		{
			Tools.DrawRectangleWithBorderAndFill(x, y, width, height, 2, GlobalColors.BRUSH_PINK, GlobalColors.BRUSH_RED);

			label_01.HandleGameTick();
			label_02.HandleGameTick();

			if (hasThreeTexts)
			{
				label_03.HandleGameTick();
			}

		}
	}
}