﻿using System;
using System.Drawing;
using BlockMania.Global;
using BlockMania.Util;
using BlockMania.Util.BlockTools;

namespace BlockMania.View
{
	internal static class PreviewField
	{
		private static Block block;

		private static int offsetLeft;
		private static int offsetTop;

		private static readonly TextStatic title = new TextStatic(GlobalData.WINDOW_TITLE,
			FontManager.font_50, GlobalColors.BRUSH_YELLOW,
			GlobalData.PREVIEW_FIELD_LOCATION_X - 60,
			GlobalData.GAME_FIELD_LOCATION_Y - 10);

		internal static Block GetBlock()
		{
			return block;
		}

		internal static void SetRandomBlock()
		{
			set_block(BlockTool.CreateRandomBlock());
		}

		internal static void SetBlockByNumber(int number)
		{
			set_block(BlockTool.CeateBlock(number));
		}

		internal static void SetNextBlock()
		{
			set_block(BlockTool.CreateNextBlock());
		}

		private static void set_block(Block b)
		{
			block = b;
			offsetLeft = (int) Math.Floor((GlobalData.PREVIEW_FIELD_WIDTH  - block.widthInPixels)  / 2.0);
			offsetTop  = (int) Math.Floor((GlobalData.PREVIEW_FIELD_HEIGHT - block.heightInPixels) / 2.0);
		}
		
		internal static void Render()
		{
			DrawPreviewField();
			DrawPreviewBlock();
		}

		private static void DrawPreviewField()
		{
			title.HandleGameTick();

			const int x = GlobalData.PREVIEW_FIELD_LOCATION_X;
			const int y = GlobalData.PREVIEW_FIELD_LOCATION_Y;

			const int width  = GlobalData.PREVIEW_FIELD_WIDTH;
			const int height = GlobalData.PREVIEW_FIELD_HEIGHT;

			const int borderWidth = GlobalData.GAME_FIELD_BORDER_WIDTH;

			Brush borderColor = GlobalColors.GAME_FIELD_BORDER_COLOR;
			Brush fieldColor  = GlobalColors.GAME_FIELD_COLOR;

			Tools.DrawRectangleWithBorderAndFill(x, y, width, height,
				borderWidth, borderColor, fieldColor);
		}

		private static void DrawPreviewBlock()
		{
			foreach (Tile tile in block.tiles)
			{
				DrawTile(tile);
			}
		}

		private static void DrawTile(Tile tile)
		{
			int x = (tile.col * GlobalData.PREVIEW_TILE_WIDTH)  + GlobalData.PREVIEW_FIELD_LOCATION_X + offsetLeft;
			int y = (tile.row * GlobalData.PREVIEW_TILE_HEIGHT) + GlobalData.PREVIEW_FIELD_LOCATION_Y + offsetTop;

			const int WIDTH  = GlobalData.PREVIEW_TILE_WIDTH;
			const int HEIGHT = GlobalData.PREVIEW_TILE_HEIGHT;

			Tools.DrawTile(x, y, WIDTH, HEIGHT, block.colorCode);
		}

	}
}